@@ -5,7 +5,6 @@
 import multiprocessing as mp
 from sys import version_info
 import traceback
-from os.path import isfile, isdir
 from functools import partial
 from pathlib import Path
 
@@ -13,26 +12,26 @@ import numpy as np
 import mne
 from mne.io.pick import channel_type
 from qtpy.QtCore import (Qt, Slot, QStringListModel, QModelIndex, QSettings,
-                         QEvent, QObject)
+                         QEvent, QObject, QSize, QPoint)
 from qtpy.QtGui import QKeySequence, QDropEvent, QIcon
 from qtpy.QtWidgets import (QApplication, QMainWindow, QFileDialog, QSplitter,
-                            QMessageBox, QListView, QAction, QLabel, QFrame,
-                            QStatusBar, QToolBar)
+                            QMessageBox, QListView, QAction, QLabel, QFrame)
 
 from .dialogs import (AnnotationsDialog, AppendDialog, CalcDialog,
-                      ChannelPropertiesDialog, CropDialog, EpochDialog,
-                      ErrorMessageBox, EventsDialog, FilterDialog,
+                      ChannelPropertiesDialog, CropDialog, ERDSDialog,
+                      EpochDialog, ErrorMessageBox, EventsDialog, FilterDialog,
                       FindEventsDialog, HistoryDialog, InterpolateBadsDialog,
                       MetaInfoDialog, MontageDialog, PickChannelsDialog,
                       ReferenceDialog, RunICADialog, XDFStreamsDialog)
 from .widgets.infowidget import InfoWidget
 from .model import LabelsNotFoundError, InvalidAnnotationsError
-from .utils import have, has_locations, image_path
+from .utils import have, has_locations, image_path, interface_style
 from .io import writers
 from .io.xdf import get_xml, get_streams
+from .viz import plot_erds
 
 
-__version__ = "0.5.5"
+__version__ = "0.6.0"
 
 MAX_RECENT = 6  # maximum number of recent files
 
@@ -43,35 +42,21 @@ def read_settings():
     Returns
     -------
     settings : dict
-        The restored settings values are returned in a dictionary for further
-        processing.
+        Settings values.
     """
-    settings = QSettings()
-
-    recent = settings.value("recent")
-    if not recent:
-        recent = []  # default is empty list
-
-    toolbar = settings.value("toolbar")
-    if toolbar is None:  # default is True
-        toolbar = True
-
-    statusbar = settings.value("statusbar")
-    if statusbar is None:  # default is True
-        statusbar = True
-
-    geometry = settings.value("geometry")
-    state = settings.value("state")
-
-    return {"recent": recent, "statusbar": statusbar, "geometry": geometry,
-            "state": state, "toolbar": toolbar}
+    settings = {}
+    settings["recent"] = QSettings().value("recent", [])
+    settings["toolbar"] = QSettings().value("toolbar", True)
+    settings["statusbar"] = QSettings().value("statusbar", True)
+    settings["size"] = QSettings().value("size", QSize(700, 500))
+    settings["pos"] = QSettings().value("pos", QPoint(100, 100))
+    return settings
 
 
 def write_settings(**kwargs):
     """Write application settings."""
-    settings = QSettings()
     for key, value in kwargs.items():
-        settings.setValue(key, value)
+        QSettings().setValue(key, value)
 
 
 class MainWindow(QMainWindow):
@@ -92,20 +77,18 @@ class MainWindow(QMainWindow):
         # restore settings
         settings = read_settings()
         self.recent = settings["recent"]  # list of recent files
-        if settings["geometry"]:
-            self.restoreGeometry(settings["geometry"])
-        else:
-            self.setGeometry(300, 300, 1000, 750)  # default window size
-            self.move(QApplication.screens()[0].geometry().center() -
-                      self.rect().center())
-        if settings["state"]:
-            self.restoreState(settings["state"])
+        self.resize(settings["size"])
+        self.move(settings["pos"])
+
+        # trigger theme setting
+        QIcon.setThemeSearchPaths([str(Path(__file__).parent / "icons")])
+        self.event(QEvent(QEvent.PaletteChange))
 
         self.actions = {}  # contains all actions
 
         # initialize menus
         file_menu = self.menuBar().addMenu("&File")
-        icon = QIcon(image_path("open_file.svg"))
+        icon = QIcon.fromTheme("open-file")
         self.actions["open_file"] = file_menu.addAction(
             icon, "&Open...", self.open_data, QKeySequence.Open)
         self.recent_menu = file_menu.addMenu("Open recent")
@@ -121,7 +104,7 @@ class MainWindow(QMainWindow):
             "Close all",
             self.close_all)
         file_menu.addSeparator()
-        icon = QIcon(image_path("meta_info.svg"))
+        icon = QIcon.fromTheme("meta-info")
         self.actions["meta_info"] = file_menu.addAction(icon,
                                                         "Show information...",
                                                         self.meta_info)
@@ -174,7 +157,7 @@ class MainWindow(QMainWindow):
         self.actions["pick_chans"] = edit_menu.addAction(
             "P&ick channels...",
             self.pick_channels)
-        icon = QIcon(image_path("chan_props.svg"))
+        icon = QIcon.fromTheme("chan-props")
         self.actions["chan_props"] = edit_menu.addAction(
             icon, "Channel &properties...", self.channel_properties)
         self.actions["set_montage"] = edit_menu.addAction("Set &montage...",
@@ -196,15 +179,17 @@ class MainWindow(QMainWindow):
             self.append_data)
 
         plot_menu = self.menuBar().addMenu("&Plot")
-        icon = QIcon(image_path("plot_data.svg"))
+        icon = QIcon.fromTheme("plot-data")
         self.actions["plot_data"] = plot_menu.addAction(icon, "&Data...",
                                                         self.plot_data)
-        icon = QIcon(image_path("plot_psd.svg"))
+        icon = QIcon.fromTheme("plot-psd")
         self.actions["plot_psd"] = plot_menu.addAction(
             icon, "&Power spectral density...", self.plot_psd)
-        icon = QIcon(image_path("plot_locations.svg"))
+        icon = QIcon.fromTheme("plot-locations")
         self.actions["plot_locations"] = plot_menu.addAction(
             icon, "&Channel locations...", self.plot_locations)
+        self.actions["plot_erds"] = plot_menu.addAction(
+            "&ERDS maps...", self.plot_erds)
         plot_menu.addSeparator()
         self.actions["plot_ica_components"] = plot_menu.addAction(
             "ICA &components...", self.plot_ica_components)
@@ -212,16 +197,19 @@ class MainWindow(QMainWindow):
             "ICA &sources...", self.plot_ica_sources)
 
         tools_menu = self.menuBar().addMenu("&Tools")
-        icon = QIcon(image_path("filter.svg"))
+        icon = QIcon.fromTheme("filter-data")
         self.actions["filter"] = tools_menu.addAction(icon, "&Filter data...",
                                                       self.filter_data)
-        icon = QIcon(image_path("find_events.svg"))
+        icon = QIcon.fromTheme("find-events")
         self.actions["find_events"] = tools_menu.addAction(icon,
                                                            "Find &events...",
                                                            self.find_events)
         self.actions["events_from_annotations"] = tools_menu.addAction(
             "Create events from annotations", self.events_from_annotations
         )
+        self.actions["annotations_from_events"] = tools_menu.addAction(
+            "Create annotations from events", self.annotations_from_events
+        )
         tools_menu.addSeparator()
         nirs_menu = tools_menu.addMenu("NIRS")
         self.actions["convert_od"] = nirs_menu.addAction(
@@ -230,7 +218,7 @@ class MainWindow(QMainWindow):
                 "Convert to &haemoglobin", self.convert_bl)
 
         tools_menu.addSeparator()
-        icon = QIcon(image_path("run_ica.svg"))
+        icon = QIcon.fromTheme("run-ica")
         self.actions["run_ica"] = tools_menu.addAction(icon, "Run &ICA...",
                                                        self.run_ica)
         self.actions["apply_ica"] = tools_menu.addAction("Apply &ICA",
@@ -240,7 +228,7 @@ class MainWindow(QMainWindow):
                                                 "Interpolate bad channels...",
                                                 self.interpolate_bads)
         tools_menu.addSeparator()
-        icon = QIcon(image_path("epoch_data.svg"))
+        icon = QIcon.fromTheme("epoch-data")
         self.actions["epoch_data"] = tools_menu.addAction(
             icon, "Create Epochs...", self.epoch_data)
 
@@ -360,6 +348,8 @@ class MainWindow(QMainWindow):
             ica = bool(self.model.current["ica"])
             self.actions["apply_ica"].setEnabled(enabled and ica)
             self.actions["export_ica"].setEnabled(enabled and ica)
+            self.actions["plot_erds"].setEnabled(
+                enabled and self.model.current["dtype"] == "epochs")
             self.actions["plot_ica_components"].setEnabled(enabled and ica and
                                                            locations)
             self.actions["plot_ica_sources"].setEnabled(enabled and ica)
@@ -368,6 +358,8 @@ class MainWindow(QMainWindow):
             self.actions["events"].setEnabled(enabled and events)
             self.actions["events_from_annotations"].setEnabled(enabled and
                                                                annot)
+            self.actions["annotations_from_events"].setEnabled(enabled and
+                                                               events)
             self.actions["find_events"].setEnabled(
                 enabled and self.model.current["dtype"] == "raw")
             self.actions["epoch_data"].setEnabled(
@@ -387,6 +379,14 @@ class MainWindow(QMainWindow):
             self.actions["convert_bl"].setEnabled(
                     len(mne.pick_types(self.model.current["data"].info,
                         fnirs="fnirs_od")))
+            # disable unsupported exporters for epochs (all must support raw)
+            if self.model.current["dtype"] == "epochs":
+                for ext, description in writers.items():
+                    action = "export_data" + ext.replace(".", "_")
+                    if "epoch" in description[2]:
+                        self.actions[action].setEnabled(True)
+                    else:
+                        self.actions[action].setEnabled(False)
         # add to recent files
         if len(self.model) > 0:
             self._add_recent(self.model.current["fname"])
@@ -396,7 +396,7 @@ class MainWindow(QMainWindow):
         if fname is None:
             fname = QFileDialog.getOpenFileName(self, "Open raw")[0]
         if fname:
-            if not (isfile(fname) or isdir(fname)):
+            if not (Path(fname).is_file() or Path(fname).is_dir()):
                 self._remove_recent(fname)
                 QMessageBox.critical(self, "File does not exist",
                                      f"File {fname} does not exist anymore.")
@@ -444,7 +444,10 @@ class MainWindow(QMainWindow):
         """Export to file."""
         fname = QFileDialog.getSaveFileName(self, text, filter=ffilter)[0]
         if fname:
-            f(fname, ffilter)
+            try:
+                f(fname, ffilter)
+            except TypeError:
+                f(fname)
 
     def import_file(self, f, text, ffilter="*"):
         """Import file."""
@@ -589,7 +592,7 @@ class MainWindow(QMainWindow):
         self.model.history.append(hist)
         win = fig.canvas.manager.window
         win.setWindowTitle(self.model.current["name"])
-        win.findChild(QStatusBar).hide()
+        win.statusBar().hide()  # not necessary since matplotlib 3.3
         win.installEventFilter(self)  # detect if the figure is closed
 
         # prevent closing the window with the escape key
@@ -622,8 +625,7 @@ class MainWindow(QMainWindow):
                                                       show=False)
         win = fig.canvas.manager.window
         win.setWindowTitle("Montage")
-        win.findChild(QStatusBar).hide()
-        win.findChild(QToolBar).hide()
+        win.statusBar().hide()  # not necessary since matplotlib 3.3
         fig.show()
 
     def plot_ica_components(self):
@@ -633,6 +635,22 @@ class MainWindow(QMainWindow):
     def plot_ica_sources(self):
         self.model.current["ica"].plot_sources(inst=self.model.current["data"])
 
+    def plot_erds(self):
+        """Plot ERDS maps."""
+        data = self.model.current["data"]
+        t_range = [data.tmin, data.tmax]
+        f_range = [1, data.info["sfreq"] / 2]
+
+        dialog = ERDSDialog(self, t_range, f_range)
+
+        if dialog.exec_():
+            freqs = np.arange(dialog.f1, dialog.f2, dialog.step)
+            baseline = [dialog.b1, dialog.b2]
+            times = [dialog.t1, dialog.t2]
+            figs = plot_erds(data, freqs, freqs, baseline, times)
+            for fig in figs:
+                fig.show()
+
     def run_ica(self):
         """Run ICA calculation."""
 
@@ -741,6 +759,9 @@ class MainWindow(QMainWindow):
     def events_from_annotations(self):
         self.model.events_from_annotations()
 
+    def annotations_from_events(self):
+        self.model.annotations_from_events()
+
     def epoch_data(self):
         """Epoch raw data."""
         dialog = EpochDialog(self, self.model.current["events"])
@@ -957,7 +978,7 @@ class MainWindow(QMainWindow):
         event : QEvent
             Close event.
         """
-        write_settings(geometry=self.saveGeometry(), state=self.saveState())
+        write_settings(size=self.size(), pos=self.pos())
         if self.model.history:
             print("\nCommand History")
             print("===============")
@@ -972,3 +993,13 @@ class MainWindow(QMainWindow):
             if self.bads != bads:
                 self.model.history.append(f"data.info['bads'] = {bads}")
         return QObject.eventFilter(self, source, event)
+
+    def event(self, ev):
+        """Catch system events."""
+        if ev.type() == QEvent.PaletteChange:  # detect theme switches
+            style = interface_style()  # light or dark
+            if style is not None:
+                QIcon.setThemeName(style)
+            else:
+                QIcon.setThemeName("light")  # fallback
+        return super().event(ev)
